@@ -1,7 +1,8 @@
 <?php
-/* $Id: bounce_send.php,v 1.5 2004/04/15 18:31:48 indiri69 Exp $ */
+/* $Id: bounce_send.php,v 1.6 2004/04/16 21:59:39 indiri69 Exp $ */
 /* Path for SquirrelMail required files. */
 define('SM_PATH','../../');
+define('DEBUG', false);
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
@@ -192,6 +193,8 @@ if(!$useSendmail) {
         }
     }
     get_smtp_user($user, $pass);
+    if (DEBUG) sm_print_r('Initializing stream:', $temp_message, $domain, $smtpServerAddress,
+                $smtpPort, $user, $pass, $authPop);
     $stream = $deliver->initStream($temp_message,$domain,0,
                       $smtpServerAddress, $smtpPort, $user, $pass, $authPop);
     if(!$stream) {
@@ -248,10 +251,17 @@ $body = sqimap_run_command ($imapConnection, "FETCH $passed_id BODY[" . $header_
 $body = array_slice($body, 1, -1);
 $body = implode('', $body);
 
+$deliver->clean_crlf($body);
+
 $deliver->preWriteToStream($hdr_s);
+if (DEBUG) sm_print_r('Writing header', $hdr_s);
 $deliver->writeToStream($stream, $hdr_s);
+
 $deliver->preWriteToStream($body);
+if (DEBUG) sm_print_r('Writing body', $body);
 $deliver->writeToStream($stream, $body);
+
+if (DEBUG) sm_print_r('Finalizing stream');
 $deliver->finalizeStream($stream);
 
 /* Go back to the message list just like compose does */
